"""App key and secret as taken from the mammotion android app."""

APP_KEY = "34231230"
APP_SECRET = "1ba85698bb10e19c6437413b61ba3445"
APP_VERSION = "1.11.1220"
ALIYUN_DOMAIN = "api.link.aliyun.com"
MAMMOTION_DOMAIN = "https://domestic.mammotion.com"
MAMMOTION_CLIENT_ID = "MADKALUBAS"
MAMMOTION_CLIENT_SECRET = "GshzGRZJjuMUgd2sYHM7"
